import { value1 } from './main1.js';
import './generated-dep2.js';

console.log('dynamic1', value1);

export { value1 };
